@@ -589,6 +589,7 @@ handle_sequence (GstMpeg2dec * mpeg2dec, const mpeg2_info_t * info)
   GstVideoCodecState *state;
   GstVideoInfo *dinfo = &mpeg2dec->decoded_info;
   GstVideoInfo *vinfo;
+  GstVideoInfo pre_crop_info;
   GstVideoFormat format;
 
   sequence = info->sequence;
@@ -759,7 +760,13 @@ handle_sequence (GstMpeg2dec * mpeg2dec, const mpeg2_info_t * info)
 
   /* we store the codec size before cropping */
   *dinfo = *vinfo;
-  gst_video_info_set_format (dinfo, format, sequence->width, sequence->height);
+  gst_video_info_set_format (&pre_crop_info, format, sequence->width,
+      sequence->height);
+  dinfo->width = sequence->width;
+  dinfo->height = sequence->height;
+  dinfo->size = pre_crop_info.size;
+  memcpy (dinfo->stride, pre_crop_info.stride, sizeof (pre_crop_info.stride));
+  memcpy (dinfo->offset, pre_crop_info.offset, sizeof (pre_crop_info.offset));
 
   /* Mpeg2dec has 2 frame latency to produce a picture and 1 frame latency in
    * it's parser */
